==> qtjambi-qt3drender-5.15.8-sources.jar: io/qt/qt3d/render/QRenderTarget.java <==
package io.qt.qt3d.render;


/**
 * <p>Encapsulates a target (usually a frame buffer object) which the renderer can render into</p>
 * <p>Java wrapper for Qt class <a href="http://doc.qt.io/qt-5/qt3drender-qrendertarget.html">Qt3DRender::QRenderTarget</a></p>
 */
public class QRenderTarget extends io.qt.qt3d.core.QComponent
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QRenderTarget.class);
    
    
    /**
     * <p>Overloaded constructor for {@link #QRenderTarget(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QRenderTarget() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qrendertarget.html#QRenderTarget">Qt3DRender::QRenderTarget::QRenderTarget(Qt3DCore::QNode*)</a></p>
     */
    @SuppressWarnings({"exports"})
    public QRenderTarget(io.qt.qt3d.core.QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QRenderTarget instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qrendertarget.html#addOutput">Qt3DRender::QRenderTarget::addOutput(Qt3DRender::QRenderTargetOutput*)</a></p>
     */
    @io.qt.QtUninvokable
    public final void addOutput(io.qt.qt3d.render.QRenderTargetOutput output){
        addOutput_native_Qt3DRender_QRenderTargetOutput_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(output));
    }
    
    @io.qt.QtUninvokable
    private native void addOutput_native_Qt3DRender_QRenderTargetOutput_ptr(long __this__nativeId, long output);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qrendertarget.html#outputs">Qt3DRender::QRenderTarget::outputs()const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.core.QVector<io.qt.qt3d.render.QRenderTargetOutput> outputs(){
        return outputs_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QVector<io.qt.qt3d.render.QRenderTargetOutput> outputs_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qrendertarget.html#removeOutput">Qt3DRender::QRenderTarget::removeOutput(Qt3DRender::QRenderTargetOutput*)</a></p>
     */
    @io.qt.QtUninvokable
    public final void removeOutput(io.qt.qt3d.render.QRenderTargetOutput output){
        removeOutput_native_Qt3DRender_QRenderTargetOutput_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(output));
    }
    
    @io.qt.QtUninvokable
    private native void removeOutput_native_Qt3DRender_QRenderTargetOutput_ptr(long __this__nativeId, long output);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QRenderTarget(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QRenderTarget(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QRenderTarget instance, QDeclarativeConstructor constructor);
    
}

==> qtjambi-qt3drender-5.15.13-sources.jar: io/qt/qt3d/render/QRenderTarget.java <==
package io.qt.qt3d.render;


/**
 * <p>Encapsulates a target (usually a frame buffer object) which the renderer can render into</p>
 * <p>Java wrapper for Qt's class <a href="http://doc.qt.io/qt-5/qt3drender-qrendertarget.html">Qt3DRender::QRenderTarget</a></p>
 */
public class QRenderTarget extends io.qt.qt3d.core.QComponent
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QRenderTarget.class);
    
    
    /**
     * <p>Overloaded constructor for {@link #QRenderTarget(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QRenderTarget() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qrendertarget.html#QRenderTarget">Qt3DRender::QRenderTarget::QRenderTarget(Qt3DCore::QNode*)</a></p>
     */
    @SuppressWarnings({"exports"})
    public QRenderTarget(io.qt.qt3d.core.QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QRenderTarget instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qrendertarget.html#addOutput">Qt3DRender::QRenderTarget::addOutput(Qt3DRender::QRenderTargetOutput*)</a></p>
     */
    @io.qt.QtUninvokable
    public final void addOutput(io.qt.qt3d.render.QRenderTargetOutput output){
        addOutput_native_Qt3DRender_QRenderTargetOutput_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(output));
    }
    
    @io.qt.QtUninvokable
    private native void addOutput_native_Qt3DRender_QRenderTargetOutput_ptr(long __this__nativeId, long output);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qrendertarget.html#outputs">Qt3DRender::QRenderTarget::outputs()const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.core.QVector<io.qt.qt3d.render.QRenderTargetOutput> outputs(){
        return outputs_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QVector<io.qt.qt3d.render.QRenderTargetOutput> outputs_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qrendertarget.html#removeOutput">Qt3DRender::QRenderTarget::removeOutput(Qt3DRender::QRenderTargetOutput*)</a></p>
     */
    @io.qt.QtUninvokable
    public final void removeOutput(io.qt.qt3d.render.QRenderTargetOutput output){
        removeOutput_native_Qt3DRender_QRenderTargetOutput_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(output));
    }
    
    @io.qt.QtUninvokable
    private native void removeOutput_native_Qt3DRender_QRenderTargetOutput_ptr(long __this__nativeId, long output);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QRenderTarget(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QRenderTarget(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QRenderTarget instance, QDeclarativeConstructor constructor);
    
}
